@@ -1,10 +1,12 @@
 """This module implements the class EvaluatesStandAttributes."""
 
-from ml.ml40.features.functionalities.functionality import Functionality
 from datetime import date
 
+from ml.ml40.features.functionalities.functionality import Functionality
+
+
 class EvaluatesStandAttributes(Functionality):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name: Object name
@@ -12,8 +14,8 @@ class EvaluatesStandAttributes(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def calculateStandAttributes(self, input_a: bytes, input_b: date) -> str:
         pass
