@@ -2,6 +2,7 @@ import asyncio
 import sys
 
 import s3i
+import jwt
 from s3i.identity_provider import IdentityProvider, TokenType
 from s3i.directory import Directory
 from s3i.repository import Repository
@@ -63,6 +64,10 @@ class Thing:
     def entry(self):
         return self.__entry
 
+    @property
+    def token(self):
+        return self.__token
+
     @property
     def identifier(self):
         return self.__entry.identifier
@@ -70,7 +75,7 @@ class Thing:
     def run_forever(self):
         try:
             self.__setup_thing_json_sync()
-            self.__connect_to_s3i()
+            self.connect_to_s3i()
             self.loop.run_forever()
 
         except KeyboardInterrupt:
@@ -161,7 +166,7 @@ class Thing:
             **kwargs
         )
 
-    def __connect_to_s3i(self):
+    def connect_to_s3i(self):
         self.__setup_identity_provider()
         self.__setup_directory()
         if self.__is_repository:
@@ -757,3 +762,22 @@ class Thing:
             APP_LOGGER.info("[S3I]: Sending customEventReply back")
         else:
             APP_LOGGER.error("[S3I]: Sending customEventReply failed")
+
+    def verify_token(self):
+        return jwt.decode(jwt=self.__token, verify=False)
+
+    def find_broker_endpoint(self, thing_id):
+        """
+        Finds the S3I-B endpoint of a thing
+
+        :param dir_obj: S³I Directory Object
+        :type dir_obj: object
+        :param thing_id: identifier of the searched thing
+
+        """
+        thing_json = self.dir.queryThingIDBased(thing_id)
+        all_endpoints = thing_json["attributes"].get("allEndpoints", None)
+        if all_endpoints:
+            for ep in all_endpoints:
+                if "s3ib" in ep:
+                    return ep
